@@ -1,5 +1,5 @@
 get.file <-
-function(getURL,showurl=FALSE,sep="\n",quiet=TRUE,clean=FALSE)
+function(getURL,showurl=FALSE,sep="\n",quiet=TRUE,clean=FALSE,verbose=FALSE)
    {  
    if(showurl){writeLines(getURL)}
    if(exists(".ncbi2r.options")==TRUE)
@@ -11,7 +11,7 @@ function(getURL,showurl=FALSE,sep="\n",quiet=TRUE,clean=FALSE)
      } else {
      ncbi2r.options()
      }
-   webget<-suppressWarnings(tryScan(getURL,sep = sep,quiet=quiet))
+   webget<-suppressWarnings(tryScan(getURL,sep = sep,quiet=quiet,verbose=verbose))
    .ncbi2r.options$TimeStampA<<-Sys.time()
    if(clean)
       webget<-clean.xml(webget)
